==> igniteui-angular-charts-16.0.0.tgz: package/esm5/lib/PriceVolumeTrendIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { PriceVolumeTrendIndicatorStrategy } from "./PriceVolumeTrendIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var PriceVolumeTrendIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PriceVolumeTrendIndicator, _super);
    function PriceVolumeTrendIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PriceVolumeTrendIndicator.prototype.get_ul = function () {
        return new PriceVolumeTrendIndicatorStrategy();
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "ul", {
        get: function () {
            return this.get_ul();
        },
        enumerable: false,
        configurable: true
    });
    PriceVolumeTrendIndicator.prototype.get_uy = function () {
        return PriceVolumeTrendIndicator.$;
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "uy", {
        get: function () {
            return this.get_uy();
        },
        enumerable: false,
        configurable: true
    });
    PriceVolumeTrendIndicator.$t = markType(PriceVolumeTrendIndicator, 'PriceVolumeTrendIndicator', StrategyBasedIndicator.$);
    return PriceVolumeTrendIndicator;
}(StrategyBasedIndicator));
export { PriceVolumeTrendIndicator };

==> igniteui-angular-charts-17.2.1.tgz: package/esm5/lib/PriceVolumeTrendIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { PriceVolumeTrendIndicatorStrategy } from "./PriceVolumeTrendIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var PriceVolumeTrendIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PriceVolumeTrendIndicator, _super);
    function PriceVolumeTrendIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PriceVolumeTrendIndicator.prototype.bg = function () {
        return new PriceVolumeTrendIndicator();
    };
    PriceVolumeTrendIndicator.prototype.get_yz = function () {
        return new PriceVolumeTrendIndicatorStrategy();
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "yz", {
        get: function () {
            return this.get_yz();
        },
        enumerable: false,
        configurable: true
    });
    PriceVolumeTrendIndicator.prototype.get_zc = function () {
        return PriceVolumeTrendIndicator.$;
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "zc", {
        get: function () {
            return this.get_zc();
        },
        enumerable: false,
        configurable: true
    });
    PriceVolumeTrendIndicator.$t = markType(PriceVolumeTrendIndicator, 'PriceVolumeTrendIndicator', StrategyBasedIndicator.$);
    return PriceVolumeTrendIndicator;
}(StrategyBasedIndicator));
export { PriceVolumeTrendIndicator };
